Crate kcr_superset_stackable_tech

Crate kcr_superset_stackable_tech 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the superset.stackable.tech group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

superset.stackable.tech/v1alpha1

  • DruidConnection
  • SupersetCluster

Modules

v1alpha1